# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ClusterCapacityReservation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_provider_capacity_reservation_id': 'str',
        'cluster_id': 'str',
        'id': 'str',
        'match_pattern': 'str',
        'project_id': 'str'
    }

    attribute_map = {
        'cloud_provider_capacity_reservation_id': 'cloudProviderCapacityReservationId',
        'cluster_id': 'clusterId',
        'id': 'id',
        'match_pattern': 'matchPattern',
        'project_id': 'projectId'
    }

    def __init__(self, cloud_provider_capacity_reservation_id: 'str' =None, cluster_id: 'str' =None, id: 'str' =None, match_pattern: 'str' =None, project_id: 'str' =None):  # noqa: E501
        """V1ClusterCapacityReservation - a model defined in Swagger"""  # noqa: E501
        self._cloud_provider_capacity_reservation_id = None
        self._cluster_id = None
        self._id = None
        self._match_pattern = None
        self._project_id = None
        self.discriminator = None
        if cloud_provider_capacity_reservation_id is not None:
            self.cloud_provider_capacity_reservation_id = cloud_provider_capacity_reservation_id
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if id is not None:
            self.id = id
        if match_pattern is not None:
            self.match_pattern = match_pattern
        if project_id is not None:
            self.project_id = project_id

    @property
    def cloud_provider_capacity_reservation_id(self) -> 'str':
        """Gets the cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._cloud_provider_capacity_reservation_id

    @cloud_provider_capacity_reservation_id.setter
    def cloud_provider_capacity_reservation_id(self, cloud_provider_capacity_reservation_id: 'str'):
        """Sets the cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.


        :param cloud_provider_capacity_reservation_id: The cloud_provider_capacity_reservation_id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._cloud_provider_capacity_reservation_id = cloud_provider_capacity_reservation_id

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The cluster_id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1ClusterCapacityReservation.


        :param cluster_id: The cluster_id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def id(self) -> 'str':
        """Gets the id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1ClusterCapacityReservation.


        :param id: The id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def match_pattern(self) -> 'str':
        """Gets the match_pattern of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The match_pattern of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._match_pattern

    @match_pattern.setter
    def match_pattern(self, match_pattern: 'str'):
        """Sets the match_pattern of this V1ClusterCapacityReservation.


        :param match_pattern: The match_pattern of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._match_pattern = match_pattern

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1ClusterCapacityReservation.  # noqa: E501


        :return: The project_id of this V1ClusterCapacityReservation.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1ClusterCapacityReservation.


        :param project_id: The project_id of this V1ClusterCapacityReservation.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ClusterCapacityReservation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ClusterCapacityReservation') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ClusterCapacityReservation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ClusterCapacityReservation') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
